/*
 * $Id: Util.java,v 1.2 2002-09-01 15:05:12-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.table.*;

/**
 * Static class to provide utility functions for working with GUI
 * components.
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.2 $
 */
public class Util {

    /**
     * Method to set the preferred widths of JTable cells to better
     * show the contents.
     */
    public static void setJTablePreferredWidths(JTable table) {
        int viewportWidth = 0;

        TableColumnModel tcm = table.getColumnModel();
        TableModel tm = table.getModel();

        TableCellRenderer renderer =
            table.getTableHeader().getDefaultRenderer();
        for (int i = 0; i < tcm.getColumnCount(); i += 1) {
            int width = 0;

            TableColumn tc = tcm.getColumn(i);
            int column = tc.getModelIndex();

            TableCellRenderer r = tc.getHeaderRenderer();
            if (r == null) {
                r = renderer;
            }

            Component c =
                r.getTableCellRendererComponent(table, tc.getHeaderValue(),
                                                false, false, -1, i);
            width = c.getPreferredSize().width;

            for (int row = 0; row < tm.getRowCount(); row += 1) {
                r = table.getCellRenderer(row, i);
                c = r.getTableCellRendererComponent(table,
                                                    tm.getValueAt(row, column),
                                                    false, false, row, i);
                width = Math.max(width, c.getPreferredSize().width);
            }

            if (width >= 0) {
                tc.setPreferredWidth(width + tcm.getColumnMargin());
            }

            viewportWidth += tc.getPreferredWidth();
        }

        Dimension size = table.getPreferredScrollableViewportSize();
        size.width = viewportWidth;
        table.setPreferredScrollableViewportSize(size);
    }

    private Util() { }
}
/*
 * $Log: Util.java,v $
 * Revision 1.2  2002-09-01 15:05:12-07  ball
 * Moved package because it should be able to display both world and player
 * stuff.
 *
 * Revision 1.1  2002-09-01 08:50:25-07  ball
 * Initial revision
 *
 */
