/*
 * $Id: MoveCommand.java,v 1.3 2002-09-01 15:08:40-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package player;

import world.*;

/**
 * Class that implements robot move commmands.
 *
 * @see Direction
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.3 $
 */
public class MoveCommand extends Command implements Direction {
    private static final String[] argument = { "N", "S", "E", "W" };

    private int direction = NORTH;

    /**
     * Creates a robot command.
     */
    public MoveCommand() { super(); }

    public final String getName() { return "Move"; }

    /**
     * Method to set the movement direction of this command.
     *
     * @param   direction       The direction of the movement.
     *
     * @see Direction
     */
    public final void setDirection(int direction) {
        if (! (0 <= direction && direction < argument.length)) {
            throw new IllegalArgumentException("Invalid direction.");
        }

        this.direction = direction;
    }

    public final String getArguments() { return argument[direction]; }
}
/*
 * $Log: MoveCommand.java,v $
 * Revision 1.3  2002-09-01 15:08:40-07  ball
 * Made setting of command arguments consistent for all subclasses
 * of Command.
 * Added an initialization method to Strategy classes.
 * Player will submit a no-op move if the Strategy implementation
 * does not return a command.
 *
 * Revision 1.2  2002-09-01 08:38:12-07  ball
 * Properly handle direction and package arguments to server commands.
 * Move Strategy class implementations to their own package.
 * Make board two rows higher and two columns wider than the server
 * specifies.  No longer translate one-based server coordinates to
 * zero-based co-ordinates.  Make the unspecified tiles on the edges wall
 * tiles.  This removes all special handling logic because all edge tiles
 * are guaranteed to be wall tiles (and, therefore, impassable).
 *
 * Revision 1.1  2002-08-31 17:46:24-07  ball
 * Initial revision
 *
 */
