/*
 * $Id: PkgCommand.java,v 1.3 2002-09-01 15:08:40-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package player;

import java.util.*;
import world.*;

/**
 * Abstract class that implements robot package commmands.
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.3 $
 */
public abstract class PkgCommand extends Command {
    private List pkgList = new ArrayList();

    /**
     * Creates a robot command.
     */
    protected PkgCommand() { super(); }

    public final String getArguments() {
        String string = "";
        Pkg[] pkgs = getPkgs();

        for (int i = 0; i < pkgs.length; i += 1) {
            if (i > 0) {
                string += " ";
            }

            string += Integer.toString(pkgs[i].getId());
        }

        return string;
    }

    /**
     * Method to add a package to the command package list.
     *
     * @param   pkg             The package to add to the command list.
     */
    public final void pkgAdd(Pkg pkg) { pkgList.add(pkg); }

    /**
     * Method to remove a package from the command package list.
     *
     * @param   pkg             The package to remove from the command list.
     */
    public final void pkgRemove(Pkg pkg) { pkgList.remove(pkg); }

    private Pkg[] getPkgs() { return (Pkg[]) pkgList.toArray(new Pkg[0]); }
}
/*
 * $Log: PkgCommand.java,v $
 * Revision 1.3  2002-09-01 15:08:40-07  ball
 * Made setting of command arguments consistent for all subclasses
 * of Command.
 * Added an initialization method to Strategy classes.
 * Player will submit a no-op move if the Strategy implementation
 * does not return a command.
 *
 * Revision 1.2  2002-09-01 08:38:12-07  ball
 * Properly handle direction and package arguments to server commands.
 * Move Strategy class implementations to their own package.
 * Make board two rows higher and two columns wider than the server
 * specifies.  No longer translate one-based server coordinates to
 * zero-based co-ordinates.  Make the unspecified tiles on the edges wall
 * tiles.  This removes all special handling logic because all edge tiles
 * are guaranteed to be wall tiles (and, therefore, impassable).
 *
 * Revision 1.1  2002-08-31 17:46:24-07  ball
 * Initial revision
 *
 */
