/*
 * $Id: IdMap.java,v 1.3 2002-09-01 22:08:34-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package world;

import java.util.*;
import javax.swing.*;
import javax.swing.table.*;

/**
 * Class that implements an ID map.
 *
 * @see ID
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.3 $
 */
public class IdMap extends TreeMap {
    private AbstractTableModel tableModel = null;

    /**
     * Creates an ID map.
     */
    public IdMap() { super(); }

    /**
     * Gets the object from the map.
     *
     * @param   id              The ID of the requested object.
     */
    public Object get(int id) { return get(new Integer(id)); }

    /**
     * Puts the object into the map.
     *
     * @param   id              The object to be put into the map.
     */
    public Object put(ID id) { return put(new Integer(id.getId()), id); }

    /**
     * Removes the object from the map.
     *
     * @param   id              The ID of the requested object.
     */
    public Object remove(int id) { return remove(new Integer(id)); }

    /**
     * Returns a table model for displaying the IdMap.
     */
    public TableModel getTableModel() {
        if (tableModel == null) {
            tableModel = new IdMapTableModel(this);
        }

        return tableModel;
    }
}
/*
 * $Log: IdMap.java,v $
 * Revision 1.3  2002-09-01 22:08:34-07  ball
 * Removed extra GUI support from IdMap and subclasses -- The GUI used in
 * development will be updated at the end of every turn.
 * The Position class implements Comparable.  Also added a toString()
 * method suitable for displaying the coordinates of the position.
 * Added a method to the Tile class for calculating the path between tiles.
 * Marked a water tile as "impassable."
 *
 * Revision 1.2  2002-09-01 15:10:58-07  ball
 * Tiles and Robots both use Sacks to hold packages.
 * Added standard Directions.  Added methods to Tile and Position
 * to take advantage of Directions.
 * GUI is no longer World-specific.
 *
 * Revision 1.1  2002-08-31 17:52:00-07  ball
 * Initial revision
 *
 */
