/*
 * $Id: PathKey.java,v 1.1 2002-09-02 03:22:25-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package world;

import java.util.*;

/**
 * Class to record paths through tiles.
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.1 $
 */
public class PathKey implements Comparable {
    protected final Tile start;
    protected final Tile end;

    /**
     * Creates a path key.
     */
    protected PathKey(Tile start, Tile end) {
        this.start = start;
        this.end = end;
    }

    public Tile getStart() { return start; }

    public Tile getEnd() { return end; }

    /**
     * Compares this object with the specified object for order.
     * Returns a negative integer, zero, or a positive integer as this
     * object is less than, equal to, or greater than the specified
     * object.
     *
     * @param   object          The object to be compared.
     *
     * @see java.lang.Comparable
     */
    public synchronized int compareTo(Object object) {
        return getOrdinal() - ((PathKey) object).getOrdinal();
    }

    /**
     * Method to get an ordinal ordering for this path with the other
     * paths in its board.
     */
    public int getOrdinal() {
        return (start.getBoard().getRowCount()
                * start.getBoard().getColumnCount() * start.getOrdinal())
               + end.getOrdinal();
    }
}
/*
 * $Log: PathKey.java,v $
 * Revision 1.1  2002-09-02 03:22:25-07  ball
 * Initial revision
 *
 */
