/*
 * $Id: PlayerRobot.java,v 1.2 2002-09-01 08:47:52-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package world;

/**
 * Class that implements robots for the ICFP-2002 programming contest
 * entry.
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.2 $
 */
public class PlayerRobot extends Robot {
    private int money = 0;

    /**
     * Creates a player robot.
     *
     * @param   world           The world this robot resides in.
     * @param   id              The robot ID.
     * @param   money           The robot's money.
     */
    public PlayerRobot(World world, int id, int capacity, int money) {
        super(world, id, capacity);
        this.money = money;
    }

    /**
     * Method to get the robot's money.
     *
     * @return                  The robot's money.
     */
    public synchronized int getMoney() { return money; }

    /**
     * Method to set the robot's money.
     *
     * @param   money           The robot's money.
     */
    public synchronized void setMoney(int money) { this.money = money; }

    public String toString() { return "PlayerRobot"; }
}
/*
 * $Log: PlayerRobot.java,v $
 * Revision 1.2  2002-09-01 08:47:52-07  ball
 * Added position information to tiles.
 * Moved most diagnostic GUI code to World class.
 * Track player robot's actual and opponent robot's observed scores and
 * loads.  Track opponent robot's observed capacity.  Added methods to
 * manage, drop, and pick packages.
 * Add load and position columns to robot table.
 * Track game turn number.
 * Display robots on the world map.
 *
 * Revision 1.1  2002-08-31 17:52:00-07  ball
 * Initial revision
 *
 */
