/*
 * $Id: RobotMap.java,v 1.6 2002-09-02 10:13:55-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package world;

import java.util.*;
import javax.swing.*;
import javax.swing.table.*;

/**
 * Class that implements an ID map.
 *
 * @see ID
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.6 $
 */
public class RobotMap extends IdMap {
    private AbstractTableModel tableModel = null;

    /**
     * Creates an ID map.
     */
    public RobotMap() { super(); }

    /**
     * Returns a table model for displaying the RobotMap.
     */
    public TableModel getTableModel() {
        if (tableModel == null) {
            tableModel = new RobotMapTableModel();
        }

        return tableModel;
    }

    private static String[] columnNames = {
        "ID", "Type", "Score", "Capacity", "Count", "Load", "Money", "Position"
    };

    private class RobotMapTableModel extends IdMapTableModel {
        private RobotMapTableModel() { super(RobotMap.this); }

        public int getColumnCount() { return columnNames.length; }

        public String getColumnName(int column) { return columnNames[column]; }

        public Object getValueAt(int row, int column) {
            Robot robot = (Robot) super.getValueAt(row, 1);
            Object value = null;

            switch (column) {
            case 0:                     /* ID */
                value = super.getValueAt(row, column);
                break;

            case 1:                     /* Type */
                value = robot.toString();
                break;

            case 2:                     /* Score */
                value = new Integer(robot.getScore());
                break;

            case 3:                     /* Capacity */
                value = new Integer(robot.getCapacity());
                break;

            case 4:                     /* Count */
                value = new Integer(robot.getSack().getCount());
                break;

            case 5:                     /* Load */
                value = new Integer(robot.getLoad());
                break;

            case 6:                     /* Money */
                if (robot instanceof PlayerRobot) {
                    value = new Integer(((PlayerRobot) robot).getMoney());
                }
                break;

            case 7:                     /* Position */
                Tile tile = robot.getTile();
                value = "[" + tile.getColumn() + ", " + tile.getRow() + "]";
                break;

            default:
                break;
            }

            return value;
        }
    }
}
/*
 * $Log: RobotMap.java,v $
 * Revision 1.6  2002-09-02 10:13:55-07  ball
 * Better use of sets.
 * Added trail to robots.
 * Optimized path calculation code (although there are still obvious
 * optimizations to be made).
 *
 * Revision 1.5  2002-09-01 23:38:55-07  ball
 * Combined Position class with Tile class.  Removed Position class.
 *
 * Revision 1.4  2002-09-01 22:08:34-07  ball
 * Removed extra GUI support from IdMap and subclasses -- The GUI used in
 * development will be updated at the end of every turn.
 * The Position class implements Comparable.  Also added a toString()
 * method suitable for displaying the coordinates of the position.
 * Added a method to the Tile class for calculating the path between tiles.
 * Marked a water tile as "impassable."
 *
 * Revision 1.3  2002-09-01 15:10:58-07  ball
 * Tiles and Robots both use Sacks to hold packages.
 * Added standard Directions.  Added methods to Tile and Position
 * to take advantage of Directions.
 * GUI is no longer World-specific.
 *
 * Revision 1.2  2002-09-01 08:47:52-07  ball
 * Added position information to tiles.
 * Moved most diagnostic GUI code to World class.
 * Track player robot's actual and opponent robot's observed scores and
 * loads.  Track opponent robot's observed capacity.  Added methods to
 * manage, drop, and pick packages.
 * Add load and position columns to robot table.
 * Track game turn number.
 * Display robots on the world map.
 *
 * Revision 1.1  2002-08-31 17:52:00-07  ball
 * Initial revision
 *
 */
