/*
 * $Id: Sack.java,v 1.1 2002-09-01 15:10:58-07 ball Exp $
 *
 * Copyright 2002 Allen D. Ball.  All rights reserved.
 */
package world;

import java.util.*;
import javax.swing.*;
import javax.swing.table.*;

/**
 * Class that implements a container for packages.
 *
 * @author <a href="mailto:ball@iprotium.com">Allen D. Ball</a>
 * @version $Revision: 1.1 $
 */
public class Sack {
    private IdMap pkgMap = new IdMap();
    private AbstractTableModel tableModel = null;

    /**
     * Creates a sack.
     */
    public Sack() { }

    /**
     * Method to get the sack's package count.
     *
     * @return                  The sack's package count.
     */
    public synchronized int getCount() { return pkgMap.size(); }

    /**
     * Method to get the sack's total weight.
     *
     * @return                  The sack's weight.
     */
    public synchronized int getWeight() {
        Pkg[] pkgs = getPkgs();
        int weight = 0;

        for (int i = 0; i < pkgs.length; i += 1) {
            weight += pkgs[i].getWeight();
        }

        return weight;
    }

    /**
     * Method to get the sack's packages.
     *
     * @return                  The sack's weight.
     */
    public synchronized Pkg[] getPkgs() {
        return (Pkg[]) pkgMap.values().toArray(new Pkg[0]);
    }

    /**
     * Method to add a package to the sack.
     *
     * @param   pkg             The package to add to the sack.
     */
    public synchronized Pkg put(Pkg pkg) { return (Pkg) pkgMap.put(pkg); }

    /**
     * Method to remove a package from a the sack.
     *
     * @param   id              The package ID of the package to remove
     *                          from the sack.
     *
     * @return                  The package that was removed or null if
     *                          the package was not found.
     */
    public synchronized Pkg remove(int id) { return (Pkg) pkgMap.remove(id); }

    /**
     * Method to remove a package from a the sack.
     *
     * @param   pkg             The package to remove from the sack.
     *
     * @return                  The package that was removed or null if
     *                          the package was not found.
     */
    public synchronized Pkg remove(Pkg pkg) {
        return (Pkg) pkgMap.remove(pkg);
    }

    /**
     * Method to clear all packages (empty) from the sack.
     */
    public synchronized void empty() { pkgMap.clear(); }

    /**
     * Returns a table model for displaying the sack.
     */
    public TableModel getTableModel() {
        if (tableModel == null) {
            tableModel = new IdMapTableModel(pkgMap);
        }

        return tableModel;
    }
}
/*
 * $Log: Sack.java,v $
 * Revision 1.1  2002-09-01 15:10:58-07  ball
 * Initial revision
 *
 */
